@@ -5,7 +5,20 @@ from ..utils import common_functions as c_f
 
 
 class GradientReversal(torch.nn.Module):
-    def __init__(self, weight=1.0):
+    """
+    Implementation of the gradient reversal layer described in
+    [Domain-Adversarial Training of Neural Networks](https://arxiv.org/abs/1505.07818),
+    which 'leaves the input unchanged during forward propagation
+    and reverses the gradient by multiplying it
+    by a negative scalar during backpropagation.'
+    """
+
+    def __init__(self, weight: float = 1.0):
+        """
+        Arguments:
+            weight: The gradients  will be multiplied by ```-weight```
+                during the backward pass.
+        """
         super().__init__()
         self.register_buffer("weight", torch.tensor([weight]))
         pml_cf.add_to_recordable_attributes(self, "weight")
@@ -14,9 +27,11 @@ class GradientReversal(torch.nn.Module):
         self.weight[0] = new_weight
 
     def forward(self, x):
+        """"""
         return _GradientReversal.apply(x, pml_cf.to_device(self.weight, x))
 
     def extra_repr(self):
+        """"""
         return c_f.extra_repr(self, ["weight"])
 
 
